@@ -48,15 +48,16 @@ define([
         /**
          * 
          * @param {*} initialData 
-         * @param {*} extensionType      extension type: notebook/colab/lab
+         * @param {*} extensionType      extension type: notebook/colab/lab/lite
          */
         constructor(extensionType='notebook', initialData={}) {
             // initial mode
+            this.isReady = false;
             this.extensionType = extensionType;
             this.parentSelector = 'body';
             if (extensionType === 'notebook') {
                 this.parentSelector = '#site';
-            } else if (extensionType === 'colab' || extensionType === 'lab') {
+            } else if (extensionType === 'colab' || extensionType === 'lab' || extensionType === 'lite') {
                 // this.parentSelector = '.notebook-horizontal';
                 this.parentSelector = 'body';
             }
@@ -168,6 +169,10 @@ define([
                     code: 'from pandas_profiling import ProfileReport',
                     type: 'package'
                 },
+                'sweetviz': {
+                    code: 'import sweetviz',
+                    type: 'package'
+                },
                 'px': {
                     code: 'import plotly.express as px\nfrom plotly.offline import init_notebook_mode\ninit_notebook_mode(connected=True)',
                     type: 'package'
@@ -187,6 +192,22 @@ define([
                 'Counter': {
                     code: 'from collections import Counter',
                     type: 'package'
+                },
+                'joblib': {
+                    code: 'import joblib',
+                    type: 'package'
+                },
+                'scipy.stats': {
+                    code: 'from scipy import stats',
+                    type: 'package'
+                },
+                'scipy': {
+                    code: 'import scipy',
+                    type: 'package'
+                },
+                'statsmodels.api': {
+                    code: 'import statsmodels.api as sm',
+                    type: 'package'
                 }
             }
 
@@ -242,7 +263,9 @@ define([
             let packageAlias = {
                 '_vp_np': 'np',
                 '_vp_pd': 'pd',
-                '_vp_plt': 'plt'
+                '_vp_plt': 'plt',
+                '_vp_stats': 'stats',
+                '_vp_sm': 'sm'
             }
 
             for (let i = 0; i < tmpList.length; i += 2) {
@@ -273,6 +296,7 @@ define([
          * - automatically restart on jupyter kernel restart (loadVisualpython.js)
          */
         readKernelFunction() {
+            let that = this;
             // CHROME: change method to load py files ($.get -> require)
             return new Promise(function(resolve, reject) {
                 var libraryList = [ 
@@ -291,7 +315,26 @@ define([
                 libraryList.forEach(libCode => {
                     promiseList.push(vpKernel.execute(libCode, true));
                 });
-                
+
+                if (that.extensionType === 'lite') {
+                    let preInstallCode = '';
+                    let preInstallPackList = [
+                        'seaborn',
+                        'plotly',
+                        'scikit-learn',
+                        'scipy',
+                        'statsmodels'
+                    ];
+                    preInstallPackList.forEach((packName, idx) => {
+                        preInstallCode += '%pip install ' + packName
+                        if (idx < preInstallPackList.length - 1) {
+                            preInstallCode += '\n';
+                        }
+                    });
+                    // pre-install packages
+                    promiseList.push(vpKernel.execute(preInstallCode, true));
+                }
+
                 // run all promises
                 let failed = false;
                 Promise.all(promiseList).then(function(resultObj) {
@@ -441,8 +484,8 @@ define([
                         // not mounted
                         reject('Colab Drive is not mounted!');
                     })
-                } else if (that.extensionType === 'lab') {
-                    // CHROME: edited to use .visualpython files
+                } else if (that.extensionType === 'lab' || that.extensionType === 'lite') {
+                    // LAB: edited to use .visualpython files
                     that._readFromLab('', configKey).then(function(result) {
                         resolve(result);
                     }).catch(function(err) {
@@ -504,7 +547,7 @@ define([
                         // not mounted
                         reject('Colab Drive is not mounted!');
                     })
-                } else if (that.extensionType === 'lab') {
+                } else if (that.extensionType === 'lab' || that.extensionType === 'lite') {
                     // LAB: use local .visualpython files
                     that._readFromLab(configKey).then(function(result) {
                         let data = result;
@@ -582,7 +625,7 @@ define([
                             reject();
                         });
                     });
-                } else if (that.extensionType === 'lab') {
+                } else if (that.extensionType === 'lab' || that.extensionType === 'lite') {
                     // LAB: use .visualpython files
                     that.getData('', configKey).then(function(data) {
                         let newDataObj = {};
@@ -627,7 +670,7 @@ define([
                     }).catch(function(err) {
                         reject(false);
                     })
-                } else if (that.extensionType === 'lab') {
+                } else if (that.extensionType === 'lab' || that.extensionType === 'lite') {
                     // LAB: use .visualpython files
                     that.getData('', configKey).then(function(data) {
                         let dataObj = data;
@@ -816,7 +859,7 @@ define([
             let that = this;
             let nowVersion = this.getVpInstalledVersion();
             let packageName = 'visualpython';
-            if (this.extensionType === 'lab') {
+            if (this.extensionType === 'lab' || this.extensionType === 'lite') {
                 packageName = 'jupyterlab-visualpython';
             }
             this.getPackageVersion(packageName).then(function(latestVersion) {
@@ -886,6 +929,16 @@ define([
                                         ];
                                         com_interface.insertCell('markdown', info.join('\n'));
                                         com_interface.insertCell('code', '!pip install jupyterlab-visualpython --upgrade');
+                                    } else if (that.extensionType === 'lite') {
+                                        // LITE: update lab extension on lite
+                                        let info = [
+                                            '## Visual Python Upgrade',
+                                            'NOTE: ',
+                                            '- Refresh your web browser to start a new version.',
+                                            '- Save VP Note before refreshing the page.'
+                                        ];
+                                        com_interface.insertCell('markdown', info.join('\n'));
+                                        com_interface.insertCell('code', "%pip install jupyterlab-visualpython==" + latestVersion);
                                     }
 
                                     // update version_timestamp
@@ -958,7 +1011,7 @@ define([
     /**
      * Version
      */
-    Config.version = "2.3.3";
+    Config.version = "2.4.2";
 
     /**
      * Type of mode
