@@ -13,10 +13,11 @@
 // [CLASS] InfoModal
 //============================================================================
 define([
-    'text!vp_base/html/component/infoModal.html!strip',
-    'css!vp_base/css/component/infoModal.css',
+    __VP_TEXT_LOADER__('vp_base/html/component/infoModal.html'), // INTEGRATION: unified version of text loader
+    __VP_CSS_LOADER__('vp_base/css/component/infoModal'), // INTEGRATION: unified version of css loader
+    'vp_base/js/com/com_Const',
     'vp_base/js/com/component/Component'
-], function(msgHtml, msgCss, Component) {
+], function(msgHtml, msgCss, com_Const, Component) {
 
     /**
      * InfoModal
@@ -35,7 +36,7 @@ define([
         }
 
         template() {
-            return msgHtml;
+            return msgHtml.replaceAll('${vp_base}', com_Const.BASE_PATH);
         }
 
         render() {
