@@ -13,17 +13,17 @@
 // [CLASS] PDF
 //============================================================================
 define([
-    'text!vp_base/html/m_apps/pdf.html!strip',
-    'css!vp_base/css/m_apps/pdf.css',
+    __VP_TEXT_LOADER__('vp_base/html/m_apps/pdf.html'), // INTEGRATION: unified version of text loader
+    __VP_CSS_LOADER__('vp_base/css/m_apps/pdf'), // INTEGRATION: unified version of css loader
     'vp_base/js/com/com_String',
     'vp_base/js/com/com_interface',
     'vp_base/js/com/component/PopupComponent',
     'vp_base/js/com/component/FileNavigation'
 ], function(pdfHtml, pdfCss, com_String, com_interface, PopupComponent, FileNavigation) {
 
-    const PDF_SHOW     = '!pip show PyMuPDF nltk'
-    const PDF_INSTALL1 = '!pip install PyMuPDF'
-    const PDF_INSTALL2 = '!pip install nltk'
+    var PDF_SHOW     = '!pip show PyMuPDF nltk'
+    var PDF_INSTALL1 = '!pip install PyMuPDF'
+    var PDF_INSTALL2 = '!pip install nltk'
 
     const PDF_IMPORT   = `import pandas as pd
 import fitz
@@ -80,6 +80,12 @@ nltk.download('punkt')`;
                 vp_pdfReturn: '',
                 ...this.state
             }
+
+            if (vpConfig.extensionType === 'lite') {
+                PDF_SHOW = PDF_SHOW.replace('!', '%');
+                PDF_INSTALL1 = PDF_INSTALL1.replace('!', '%');
+                PDF_INSTALL2 = PDF_INSTALL2.replace('!', '%');
+            }
         }
 
         _bindEvent() {
