@@ -26,6 +26,20 @@ define([
 
     /**
      * Subset
+     * ====================================
+     * Special mode
+     * 1. useAsModule : Use subset as module like DataSelector
+     *      - No allocation
+     *      - No run to cell (able to use apply button instead)
+     *      - renders button to target
+     * 2. useInputVariable : Use subset as module but use applied variable
+     *      - No allocation
+     *      - No data selection
+     *      - No run to cell
+     *      - renders button to target
+     * 3. useInputColumns : Use subset as module but use applied columns
+     *      - No allocation
+     *      - No column selection
      */
     class Subset extends PopupComponent {
         _init() {
@@ -39,8 +53,9 @@ define([
             this.targetSelector = this.prop.targetSelector;
             this.pageThis = this.prop.pageThis;
 
+            this.useAsModule = this.prop.useAsModule;
             this.useInputVariable = this.prop.useInputVariable;
-            if (this.useInputVariable) {
+            if (this.useInputVariable === true || this.useAsModule === true) {
                 this.eventTarget = this.targetSelector;
                 this.useCell = false; // show apply button only
             }
@@ -77,6 +92,7 @@ define([
                 useCopy: false,
                 toFrame: false,
                 subsetType: 'loc', // subset / loc / iloc / query
+                returnType: '',
 
                 rowType: 'condition',
                 rowList: [],
@@ -115,6 +131,13 @@ define([
             this.loadStateAfterRender();
             
             // render button
+            if (this.useAsModule) {
+                // render button
+                this.renderButton();
+
+                // hide allocate to
+                $(this.wrapSelector('.' + VP_DS_ALLOCATE_TO)).closest('tr').hide();
+            }
             if (this.useInputVariable) {
                 // set readonly
                 $(this.wrapSelector('.' + VP_DS_PANDAS_OBJECT)).attr('disabled', true);
@@ -162,7 +185,7 @@ define([
                 VP_DS_DATA_VIEW_ALL_DIV, VP_DS_DATA_VIEW_ALL, (this.state.viewAll?'checked':''), "view all");
             // data view
             tag.appendFormatLine('<div class="{0} {1} vp-scrollbar"></div>', VP_DS_DATA_VIEW_BOX,
-                'rendered_html'); // 'rendered_html' style from jupyter output area
+                'vp_rendered_html'); // 'rendered_html' style from jupyter output area
             return tag.toString();
         }
         getAllowSubsetTypes() {
@@ -175,7 +198,7 @@ define([
             buttonTag.appendFormat('<button type="button" class="{0} {1} {2}">{3}</button>',
                 VP_DS_BTN, this.uuid, 'vp-button', 'Subset');
             if (this.pageThis) {
-                $(this.targetSelector).parent().append(buttonTag.toString());
+                $(buttonTag.toString()).insertAfter($(this.targetSelector));
             }
         }
         renderSubsetType(dataType) {
@@ -324,7 +347,7 @@ define([
                     let subsetVariable = com_util.formatString('{0}.iloc[{1}:{2}]', that.state.pandasObject, start, end);
                     vpKernel.getRowList(subsetVariable).then(function (resultObj) {
                         let { result } = resultObj;
-                        var rowList = JSON.parse(result);
+                        var { list:rowList } = JSON.parse(result);
                         rowList = rowList.map(function (x) {
                             return {
                                 ...x,
@@ -500,8 +523,14 @@ define([
                 // col.array parsing
                 var colInfo = com_util.safeString(col.array);
                 // render column box
-                tag.appendFormatLine('<div class="{0} {1} {2}" data-idx="{3}" data-colname="{4}" data-dtype="{5}" data-code="{6}" title="{7}"><span>{8}</span></div>',
-                    VP_DS_SELECT_ITEM, 'select-col', VP_DS_DRAGGABLE, col.location, col.value, col.dtype, col.code, col.label + ': \n' + colInfo, col.label);
+                let numIconStr = '';
+                if (col.isNumeric === true) {
+                    numIconStr = '<span class="vp-icon-numeric mr5 vp-vertical-text"></span>';
+                } else {
+                    numIconStr = '<span class="vp-icon-non-numeric mr5 vp-vertical-text"></span>';
+                }
+                tag.appendFormatLine('<div class="{0} {1} {2}" data-idx="{3}" data-colname="{4}" data-dtype="{5}" data-code="{6}" title="{7}">{8}<span>{9}</span></div>',
+                    VP_DS_SELECT_ITEM, 'select-col', VP_DS_DRAGGABLE, col.location, col.value, col.dtype, col.code, col.label + ': \n' + colInfo, numIconStr, col.label);
             });
             tag.appendLine('</div>'); // VP_DS_SELECT_BOX
             $(this.wrapSelector('.select-col .' + VP_DS_SELECT_BOX + '.left')).replaceWith(function () {
@@ -563,6 +592,7 @@ define([
         renderColumnConditionList(colList) {
             var tag = new com_String();
             tag.appendFormatLine('<table class="{0}">', VP_DS_CONDITION_TBL);
+            tag.appendLine(this.templateForConditionBox(colList));
             tag.appendLine('<tr>');
             tag.appendFormatLine('<td colspan="4"><button type="button" class="{0} {1}">{2}</button></td>',
                 VP_DS_BUTTON_ADD_CONDITION, 'vp-add-col', '+ Condition');
@@ -743,6 +773,7 @@ define([
                         var varType = JSON.parse(result);
                         that.state.pandasObject = prevValue;
                         that.state.dataType = varType;
+                        that.state.returnType = varType;
                         $(that.wrapSelector('.' + VP_DS_PANDAS_OBJECT_BOX)).replaceWith(function () {
                             return $(com_util.formatString('<div style="display:inline-block"><input class="{0} {1}" value="{2}" disabled /></div>',
                                 'vp-input', VP_DS_PANDAS_OBJECT, prevValue));
@@ -783,6 +814,7 @@ define([
                         $(this.wrapSelector()).data('dtype', item.dtype);
                         that.state.pandasObject = value;
                         that.state.dataType = item.dtype;
+                        that.state.returnType = item.dtype;
                         $(this.wrapSelector()).trigger('change');
                     });
                     variableInput.setNormalFilter(true);
@@ -1161,6 +1193,7 @@ define([
 
                 that.state.pandasObject = varName;
                 that.state.dataType = event.dataType ? event.dataType : that.state.dataType;
+                that.state.returnType = that.state.dataType;
                 that.state.rowList = [];
                 that.state.rowLimit = 10;
                 that.state.columnList = [];
@@ -1179,15 +1212,16 @@ define([
                     // get result and load column list
                     vpKernel.getColumnList(varName).then(function (resultObj) {
                         let { result } = resultObj;
-                        var colList = JSON.parse(result);
-                        colList = colList.map(function (x) {
+                        var { list } = JSON.parse(result);
+                        list = list.map(function (x) {
                             return {
                                 ...x,
                                 value: x.label,
                                 code: x.value,
+                                isNumeric: x.is_numeric
                             };
                         });
-                        that.loadColumnList(colList);
+                        that.loadColumnList(list);
                         that.bindDraggable('col');
                         that.generateCode();
                     });
@@ -1196,7 +1230,7 @@ define([
                     let subsetVariable = com_util.formatString('{0}.iloc[:{1}]', varName, that.state.rowLimit);
                     vpKernel.getRowList(subsetVariable).then(function (resultObj) {
                         let { result } = resultObj;
-                        var rowList = JSON.parse(result);
+                        var { list:rowList } = JSON.parse(result);
                         rowList = rowList.map(function (x) {
                             return {
                                 ...x,
@@ -1229,7 +1263,7 @@ define([
                     let subsetVariable = com_util.formatString('{0}.iloc[:{1}]', varName, that.state.rowLimit);
                     vpKernel.getRowList(subsetVariable).then(function (resultObj) {
                         let { result } = resultObj;
-                        var rowList = JSON.parse(result);
+                        var { list:rowList } = JSON.parse(result);
                         rowList = rowList.map(function (x) {
                             return {
                                 ...x,
@@ -1813,10 +1847,14 @@ define([
                 if (this.state.colType == 'indexing') {
                     if (this.useInputColumns == true) {
                         colList = this.state.selectedColumns;
-                        if (colList.length == 1) {
-                            colSelection.appendFormat('{0}', colList.toString());
-                        } else {
-                            colSelection.appendFormat('[{0}]', colList.toString());
+                        if (colList.length > 0) {
+                            if (colList.length == 1) {
+                                colSelection.appendFormat('{0}', colList.toString());
+                                this.state.returnType = 'Series';
+                            } else {
+                                colSelection.appendFormat('[{0}]', colList.toString());
+                                this.state.returnType = 'DataFrame';
+                            }
                         }
                     } else {
                         var colTags = $(this.wrapSelector('.' + VP_DS_SELECT_ITEM + '.select-col.added:not(.moving)'));
@@ -1836,11 +1874,14 @@ define([
                                 // to frame
                                 if (this.state.toFrame) {
                                     colSelection.appendFormat('[{0}]', colList.toString());
+                                    this.state.returnType = 'DataFrame';
                                 } else {
                                     colSelection.appendFormat('{0}', colList.toString());
+                                    this.state.returnType = 'Series';
                                 }
                             } else {
                                 colSelection.appendFormat('[{0}]', colList.toString());
+                                this.state.returnType = 'DataFrame';
                             }
     
                         } else {
@@ -1855,31 +1896,34 @@ define([
             }
 
             // use simple selection
-            if (this.state.subsetType == 'subset') {
-                if (rowSelection.toString() != ':' && rowSelection.toString() != '') {
-                    code.appendFormat('[{0}]', rowSelection.toString());
-                }
-                if (colSelection.toString() != ':' && colSelection.toString() != '') {
-                    code.appendFormat('[{0}]', colSelection.toString());
-                }
-            } else if (this.state.subsetType == 'loc') {
-                if (this.state.dataType == 'DataFrame') {
-                    code.appendFormat('.loc[{0}, {1}]', rowSelection.toString(), colSelection.toString());
-                } else {
-                    code.appendFormat('.loc[{0}]', rowSelection.toString());
-                }
-            } else if (this.state.subsetType == 'iloc') {
-                if (this.state.dataType == 'DataFrame') {
-                    code.appendFormat('.iloc[{0}, {1}]', rowSelection.toString(), colSelection.toString());
-                } else {
-                    code.appendFormat('.iloc[{0}]', rowSelection.toString());
-                }
-            } else if (this.state.subsetType == 'query') {
-                if (rowSelection.toString() != ':' && rowSelection.toString() != '') {
-                    code.appendFormat('.query("{0}")', rowSelection.toString());
-                }
-                if (colSelection.toString() != ':' && colSelection.toString() != '') {
-                    code.appendFormat('[{0}]', colSelection.toString());
+            if ((rowSelection.toString() !== ':' && rowSelection.toString() !== '')
+                || (colSelection.toString() !== ':' && colSelection.toString() !== '')) {
+                if (this.state.subsetType == 'subset') {
+                    if (rowSelection.toString() != ':' && rowSelection.toString() != '') {
+                        code.appendFormat('[{0}]', rowSelection.toString());
+                    }
+                    if (colSelection.toString() != ':' && colSelection.toString() != '') {
+                        code.appendFormat('[{0}]', colSelection.toString());
+                    }
+                } else if (this.state.subsetType == 'loc') {
+                    if (this.state.dataType == 'DataFrame') {
+                        code.appendFormat('.loc[{0}, {1}]', rowSelection.toString(), colSelection.toString());
+                    } else {
+                        code.appendFormat('.loc[{0}]', rowSelection.toString());
+                    }
+                } else if (this.state.subsetType == 'iloc') {
+                    if (this.state.dataType == 'DataFrame') {
+                        code.appendFormat('.iloc[{0}, {1}]', rowSelection.toString(), colSelection.toString());
+                    } else {
+                        code.appendFormat('.iloc[{0}]', rowSelection.toString());
+                    }
+                } else if (this.state.subsetType == 'query') {
+                    if (rowSelection.toString() != ':' && rowSelection.toString() != '') {
+                        code.appendFormat('.query("{0}")', rowSelection.toString());
+                    }
+                    if (colSelection.toString() != ':' && colSelection.toString() != '') {
+                        code.appendFormat('[{0}]', colSelection.toString());
+                    }
                 }
             }
 
@@ -1911,9 +1955,11 @@ define([
             if (this.useInputVariable) {
                 this.loadVariables();
                 this.reloadSubsetData();
+            }        
+            if (this.useCell === false) {
                 // show save button only
                 this.setSaveOnlyMode();
-            }        
+            }
             // generate code after displaying page
             // - codemirror can be set after display    
             this.generateCode();
@@ -1924,13 +1970,13 @@ define([
         //====================================================================
 
         hideButton() {
-            if (this.useInputVariable) {
+            if (this.useInputVariable === true || this.useAsModule === true) {
                 $(this.pageThis.wrapSelector('.' + VP_DS_BTN + '.' + this.uuid)).hide();
             }
         }
 
         disableButton() {
-            if (this.useInputVariable) {
+            if (this.useInputVariable === true || this.useAsModule === true) {
                 var buttonEle = $(this.pageThis.wrapSelector('.' + VP_DS_BTN + '.' + this.uuid));
                 if (!buttonEle.hasClass('disabled')) {
                     buttonEle.addClass('disabled');
@@ -1939,12 +1985,12 @@ define([
         }
 
         enableButton() {
-            if (this.useInputVariable) {
+            if (this.useInputVariable === true || this.useAsModule === true) {
                 $(this.pageThis.wrapSelector('.' + VP_DS_BTN + '.' + this.uuid)).removeClass('disabled');
             }
         }
         showButton() {
-            if (this.useInputVariable) {
+            if (this.useInputVariable === true || this.useAsModule === true) {
                 $(this.pageThis.wrapSelector('.' + VP_DS_BTN + '.' + this.uuid)).show();
             }
         }
