@@ -31,7 +31,7 @@ define([
             super._init();
             /** Write codes executed before rendering */
             this.config.sizeLevel = 2;
-            this.config.checkModules = ['pd', 'np', 'vp_confidence_interval', 'vp_sem'];
+            this.config.checkModules = ['pd', 'np', 'scipy.stats', 'vp_confidence_interval', 'vp_sem'];
 
             this.state = {
                 testType: 'one-way',
@@ -188,7 +188,7 @@ define([
                         code.appendLine();
                         code.appendLine("# Statistics");
                         code.appendLine("display(Markdown('### Statistics'))");
-                        code.appendLine("display(pd.DataFrame(data={'Count':_df.count(),'Mean':_df.mean(),'Std. Deviation':_df.std(),'Min':_df.min(),'Max':_df.max(),");
+                        code.appendLine("display(pd.DataFrame(data={'Count':_df.count(),'Mean':_df.mean(numeric_only=True),'Std. Deviation':_df.std(numeric_only=True),'Min':_df.min(),'Max':_df.max(),");
                         code.appendLine("                           'Std. Error Mean':_df.apply(vp_sem),'Confidence interval':0.95,");
                         code.append("                           'Lower':_df.apply(vp_confidence_interval).T[0],'Upper':_df.apply(vp_confidence_interval).T[1] }))");
                     }
@@ -252,7 +252,11 @@ define([
                     }
 
                     if (tukey === true || scheffe === true || duncan === true) {
-                        codeList.push("!pip install scikit-posthocs");
+                        if (vpConfig.extensionType === 'lite') {
+                            codeList.push("%pip install scikit-posthocs");
+                        } else {
+                            codeList.push("!pip install scikit-posthocs");
+                        }
 
                         // Post hoc analysis - Tukey
                         if (tukey === true) {
@@ -303,7 +307,7 @@ define([
                         code.appendLine();
                         code.appendLine("# Statistics");
                         code.appendLine("display(Markdown('### Statistics'))");
-                        code.appendLine("display(pd.DataFrame(data={'Count':_df.count(),'Mean':_df.mean(),'Std. Deviation':_df.std(),'Min':_df.min(),'Max':_df.max(),");
+                        code.appendLine("display(pd.DataFrame(data={'Count':_df.count(),'Mean':_df.mean(numeric_only=True),'Std. Deviation':_df.std(numeric_only=True),'Min':_df.min(),'Max':_df.max(),");
                         code.appendLine("                   'Std. Error Mean':_df.apply(vp_sem),'Confidence interval':0.95,");
                         code.append("                   'Lower':_df.apply(vp_confidence_interval).T[0],'Upper':_df.apply(vp_confidence_interval).T[1] }))");
                     }
@@ -379,7 +383,11 @@ define([
                     }
                     if (tukey === true || scheffe === true || duncan === true) {
                         // Add installation code
-                        codeList.push("!pip install scikit-posthocs");
+                        if (vpConfig.extensionType === 'lite') {
+                            codeList.push("%pip install scikit-posthocs");
+                        } else {
+                            codeList.push("!pip install scikit-posthocs");
+                        }
 
                         // Post hoc analysis - Tukey
                         if (tukey === true) {
@@ -427,7 +435,7 @@ define([
                         code.appendLine();
                         code.appendLine("# Statistics");
                         code.appendLine("display(Markdown('### Statistics'))");
-                        code.appendLine("display(pd.DataFrame(data={'Count':_df.count(),'Mean':_df.mean(),'Std. Deviation':_df.std(),'Min':_df.min(),'Max':_df.max(),");
+                        code.appendLine("display(pd.DataFrame(data={'Count':_df.count(),'Mean':_df.mean(numeric_only=True),'Std. Deviation':_df.std(numeric_only=True),'Min':_df.min(),'Max':_df.max(),");
                         code.appendLine("                   'Std. Error Mean':_df.apply(vp_sem),'Confidence interval':0.95,");
                         code.append("                   'Lower':_df.apply(vp_confidence_interval).T[0],'Upper':_df.apply(vp_confidence_interval).T[1] }))");
                     }
@@ -445,7 +453,11 @@ define([
                     }
 
                     // Add installation code : # pip install pingouin
-                    codeList.push("!pip install pingouin");
+                    if (vpConfig.extensionType === 'lite') {
+                        codeList.push("%pip install pingouin");
+                    } else {
+                        codeList.push("!pip install pingouin");
+                    }
 
                     code.appendLine();
                     code.appendLine();
