@@ -23,13 +23,14 @@ define([
     '../com/component/Component',
     '../com/component/SuggestInput',
     '../com/component/InnerFuncViewer',
+    '../com/component/PackageManager',
 
     __VP_RAW_LOADER__('../../data/libraries.json'), // INTEGRATION: text! to raw-loader
 
     './MenuGroup',
     './MenuItem',
     './TaskBar'
-], function(menuFrameHtml, menuFrameCss, com_Config, com_Const, com_util, com_interface, Component, SuggestInput, InnerFuncViewer,
+], function(menuFrameHtml, menuFrameCss, com_Config, com_Const, com_util, com_interface, Component, SuggestInput, InnerFuncViewer, PackageManager,
             librariesJson, 
             MenuGroup, MenuItem, TaskBar) {
 	'use strict';
@@ -114,6 +115,11 @@ define([
             $(this.wrapSelector('#vp_versionUpdater')).on('click', function() {
                 vpConfig.checkVpVersion();
             });
+            // Click package manager
+            $(this.wrapSelector('#vp_packageManager')).on('click', function() {
+                let packageManager = new PackageManager();
+                packageManager.open();
+            });
         }
 
         _unbindResizable() {
@@ -182,7 +188,7 @@ define([
         getMenuLibraries() {
             var libraries = {};
             // LAB: webpack5 load json object by default
-            if (vpConfig.extensionType === 'lab') {
+            if (vpConfig.extensionType === 'lab' || vpConfig.extensionType === 'lite') {
                 libraries = librariesJson;
             } else {
                 libraries = JSON.parse(librariesJson);
@@ -236,6 +242,9 @@ define([
             //     }
             // }
             // this.$pageDom = $(replaceHtml);
+            
+            // add hover title for logo
+            this.$pageDom.find('.vp-logo').prop('title', com_Const.TOOLBAR_BTN_INFO.HELP);
             return this.$pageDom;
         }
 
@@ -257,8 +266,8 @@ define([
                     }
                 } else {
                     // functions : MenuItem
+                    that.menuLibrariesFlatten.push(child);
                     if (!child.hide) {
-                        that.menuLibrariesFlatten.push(child);
                         var menuItem = new MenuItem($(body), child);
                     }
                 }
